@@ -32,6 +32,20 @@ impl TransportUnicastLowlatency {
         #[allow(unused_mut)] // shared-memory feature requires mut
         mut msg: NetworkMessage,
     ) -> ZResult<()> {
+        #[cfg(feature = "stats")]
+        {
+            #[cfg(feature = "shared-memory")]
+            {
+                use zenoh_protocol::network::NetworkMessageExt;
+                if msg.is_shm() {
+                    self.stats.rx_n_msgs.inc_shm(1);
+                } else {
+                    self.stats.rx_n_msgs.inc_net(1);
+                }
+            }
+            #[cfg(not(feature = "shared-memory"))]
+            self.stats.rx_n_msgs.inc_net(1);
+        }
         let callback = zread!(self.callback).clone();
         if let Some(callback) = callback.as_ref() {
             #[cfg(feature = "shared-memory")]
