@@ -23,22 +23,16 @@ use std::{
 use tokio::sync::{Mutex as AsyncMutex, MutexGuard as AsyncMutexGuard};
 #[cfg(feature = "transport_compression")]
 use zenoh_config::CompressionUnicastConf;
-#[cfg(feature = "shared-memory")]
-use zenoh_config::ShmConf;
 use zenoh_config::{Config, LinkTxConf, QoSUnicastConf, TransportUnicastConf};
 use zenoh_core::{zasynclock, zcondfeat};
 use zenoh_crypto::PseudoRng;
 use zenoh_link::*;
 use zenoh_protocol::{
-    core::{parameters, ZenohIdProto},
+    core::{parameters, Reliability, ZenohIdProto},
     transport::{close, TransportSn},
 };
 use zenoh_result::{bail, zerror, ZResult};
-#[cfg(feature = "shared-memory")]
-use zenoh_shm::reader::ShmReader;
 
-#[cfg(feature = "shared-memory")]
-use super::establishment::ext::shm::AuthUnicast;
 use super::{link::LinkUnicastWithOpenAck, transport_unicast_inner::InitTransportResult};
 #[cfg(feature = "stats")]
 use crate::stats::TransportStats;
@@ -70,17 +64,46 @@ pub struct TransportManagerConfigUnicast {
     pub is_lowlatency: bool,
     #[cfg(feature = "transport_multilink")]
     pub max_links: usize,
-    #[cfg(feature = "shared-memory")]
-    pub is_shm: bool,
     #[cfg(feature = "transport_compression")]
     pub is_compression: bool,
 }
 
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+pub struct LinkKey {
+    protocol: String,
+    reliability: Option<Reliability>,
+}
+
+impl LinkKey {
+    pub fn with_protocol(protocol: &str) -> Self {
+        LinkKey {
+            protocol: protocol.to_string(),
+            reliability: None,
+        }
+    }
+}
+
+impl From<&EndPoint> for LinkKey {
+    fn from(endpoint: &EndPoint) -> Self {
+        let protocol = endpoint.protocol().to_string();
+        let reliability = Reliability::from(
+            LocatorInspector::default()
+                .is_reliable(&endpoint.to_locator())
+                .expect("endpoint protocol should be valid"),
+        );
+
+        Self {
+            protocol,
+            reliability: Some(reliability),
+        }
+    }
+}
+
 pub struct TransportManagerStateUnicast {
     // Incoming uninitialized transports
     pub(super) incoming: Arc<AtomicUsize>,
     // Established listeners
-    pub(super) protocols: Arc<AsyncMutex<HashMap<String, LinkManagerUnicast>>>,
+    pub(super) link_managers: Arc<AsyncMutex<HashMap<LinkKey, LinkManagerUnicast>>>,
     // Established transports
     pub(super) transports: Arc<AsyncMutex<HashMap<ZenohIdProto, Arc<dyn TransportUnicastTrait>>>>,
     // Multilink
@@ -89,10 +112,6 @@ pub struct TransportManagerStateUnicast {
     // Active authenticators
     #[cfg(feature = "transport_auth")]
     pub(super) authenticator: Arc<Auth>,
-    // SHM probing
-    // Option will be None if SHM is disabled by Config
-    #[cfg(feature = "shared-memory")]
-    pub(super) auth_shm: Option<AuthUnicast>,
 }
 
 pub struct TransportManagerParamsUnicast {
@@ -115,8 +134,6 @@ pub struct TransportManagerBuilderUnicast {
     pub(super) is_qos: bool,
     #[cfg(feature = "transport_multilink")]
     pub(super) max_links: usize,
-    #[cfg(feature = "shared-memory")]
-    pub(super) is_shm: bool,
     #[cfg(feature = "transport_auth")]
     pub(super) authenticator: Auth,
     pub(super) is_lowlatency: bool,
@@ -177,12 +194,6 @@ impl TransportManagerBuilderUnicast {
         self
     }
 
-    #[cfg(feature = "shared-memory")]
-    pub fn shm(mut self, is_shm: bool) -> Self {
-        self.is_shm = is_shm;
-        self
-    }
-
     #[cfg(feature = "transport_compression")]
     pub fn compression(mut self, is_compression: bool) -> Self {
         self.is_compression = is_compression;
@@ -209,10 +220,6 @@ impl TransportManagerBuilderUnicast {
         {
             self = self.max_links(*config.transport().unicast().max_links());
         }
-        #[cfg(feature = "shared-memory")]
-        {
-            self = self.shm(*config.transport().shared_memory().enabled());
-        }
         #[cfg(feature = "transport_auth")]
         {
             self = self.authenticator(Auth::from_config(config).await?);
@@ -228,7 +235,6 @@ impl TransportManagerBuilderUnicast {
     pub fn build(
         self,
         #[allow(unused)] prng: &mut PseudoRng, // Required for #[cfg(feature = "transport_multilink")]
-        #[cfg(feature = "shared-memory")] shm_reader: &ShmReader,
     ) -> ZResult<TransportManagerParamsUnicast> {
         if self.is_qos && self.is_lowlatency {
             bail!("'qos' and 'lowlatency' options are incompatible");
@@ -244,8 +250,6 @@ impl TransportManagerBuilderUnicast {
             is_qos: self.is_qos,
             #[cfg(feature = "transport_multilink")]
             max_links: self.max_links,
-            #[cfg(feature = "shared-memory")]
-            is_shm: self.is_shm,
             is_lowlatency: self.is_lowlatency,
             #[cfg(feature = "transport_compression")]
             is_compression: self.is_compression,
@@ -253,19 +257,12 @@ impl TransportManagerBuilderUnicast {
 
         let state = TransportManagerStateUnicast {
             incoming: Arc::new(AtomicUsize::new(0)),
-            protocols: Arc::new(AsyncMutex::new(HashMap::new())),
+            link_managers: Arc::new(AsyncMutex::new(HashMap::new())),
             transports: Arc::new(AsyncMutex::new(HashMap::new())),
             #[cfg(feature = "transport_multilink")]
             multilink: Arc::new(MultiLink::make(prng, config.max_links > 1)?),
             #[cfg(feature = "transport_auth")]
             authenticator: Arc::new(self.authenticator),
-            #[cfg(feature = "shared-memory")]
-            auth_shm: match self.is_shm {
-                true => Some(AuthUnicast::new(
-                    shm_reader.supported_protocols().as_slice(),
-                )?),
-                false => None,
-            },
         };
 
         let params = TransportManagerParamsUnicast { config, state };
@@ -279,8 +276,6 @@ impl Default for TransportManagerBuilderUnicast {
         let transport = TransportUnicastConf::default();
         let link_tx = LinkTxConf::default();
         let qos = QoSUnicastConf::default();
-        #[cfg(feature = "shared-memory")]
-        let shm = ShmConf::default();
         #[cfg(feature = "transport_compression")]
         let compression = CompressionUnicastConf::default();
 
@@ -294,8 +289,6 @@ impl Default for TransportManagerBuilderUnicast {
             is_qos: *qos.enabled(),
             #[cfg(feature = "transport_multilink")]
             max_links: *transport.max_links(),
-            #[cfg(feature = "shared-memory")]
-            is_shm: *shm.enabled(),
             #[cfg(feature = "transport_auth")]
             authenticator: Auth::default(),
             is_lowlatency: *transport.lowlatency(),
@@ -316,7 +309,7 @@ impl TransportManager {
     pub async fn close_unicast(&self) {
         tracing::trace!("TransportManagerUnicast::clear())");
 
-        let mut pl_guard = zasynclock!(self.state.unicast.protocols)
+        let mut pl_guard = zasynclock!(self.state.unicast.link_managers)
             .drain()
             .map(|(_, v)| v)
             .collect::<Vec<Arc<dyn LinkManagerUnicastTrait>>>();
@@ -339,42 +332,45 @@ impl TransportManager {
     /*************************************/
     /*            LINK MANAGER           */
     /*************************************/
-    async fn new_link_manager_unicast(&self, protocol: &str) -> ZResult<LinkManagerUnicast> {
-        if !self.config.protocols.iter().any(|x| x.as_str() == protocol) {
+    async fn new_link_manager_unicast(&self, endpoint: &EndPoint) -> ZResult<LinkManagerUnicast> {
+        let protocol = endpoint.protocol().as_str();
+        let link_kind = LinkKind::try_from(endpoint)?;
+        if !self.config.supported_links.contains(&link_kind) {
             bail!(
                 "Unsupported protocol: {}. Supported protocols are: {:?}",
                 protocol,
-                self.config.protocols
+                self.config.supported_links
             );
         }
 
-        let mut w_guard = zasynclock!(self.state.unicast.protocols);
-        if let Some(lm) = w_guard.get(protocol) {
+        let mut w_guard = zasynclock!(self.state.unicast.link_managers);
+        let key = LinkKey::from(endpoint);
+        if let Some(lm) = w_guard.get(&key) {
             Ok(lm.clone())
         } else {
             let lm =
-                LinkManagerBuilderUnicast::make(self.new_unicast_link_sender.clone(), protocol)?;
-            w_guard.insert(protocol.to_string(), lm.clone());
+                LinkManagerBuilderUnicast::make(self.new_unicast_link_sender.clone(), endpoint)?;
+            w_guard.insert(key, lm.clone());
             Ok(lm)
         }
     }
 
-    async fn get_link_manager_unicast(&self, protocol: &str) -> ZResult<LinkManagerUnicast> {
-        match zasynclock!(self.state.unicast.protocols).get(protocol) {
+    async fn get_link_manager_unicast(&self, endpoint: &EndPoint) -> ZResult<LinkManagerUnicast> {
+        match zasynclock!(self.state.unicast.link_managers).get(&LinkKey::from(endpoint)) {
             Some(manager) => Ok(manager.clone()),
             None => bail!(
                 "Can not get the link manager for protocol ({}) because it has not been found",
-                protocol
+                endpoint.protocol()
             ),
         }
     }
 
-    async fn del_link_manager_unicast(&self, protocol: &str) -> ZResult<()> {
-        match zasynclock!(self.state.unicast.protocols).remove(protocol) {
+    async fn del_link_manager_unicast(&self, endpoint: &EndPoint) -> ZResult<()> {
+        match zasynclock!(self.state.unicast.link_managers).remove(&LinkKey::from(endpoint)) {
             Some(_) => Ok(()),
             None => bail!(
                 "Can not delete the link manager for protocol ({}) because it has not been found.",
-                protocol
+                endpoint.protocol()
             ),
         }
     }
@@ -394,11 +390,13 @@ impl TransportManager {
             )
         }
 
-        let manager = self
-            .new_link_manager_unicast(endpoint.protocol().as_str())
-            .await?;
+        let manager = self.new_link_manager_unicast(&endpoint).await?;
         // Fill and merge the endpoint configuration
-        if let Some(config) = self.config.endpoints.get(endpoint.protocol().as_str()) {
+        if let Some(config) = self
+            .config
+            .link_configs
+            .get(&LinkKind::try_from(&endpoint)?)
+        {
             let mut config = parameters::Parameters::from(config.as_str());
             // Overwrite config with current endpoint parameters
             config.extend_from_iter(endpoint.config().iter());
@@ -413,20 +411,17 @@ impl TransportManager {
     }
 
     pub async fn del_listener_unicast(&self, endpoint: &EndPoint) -> ZResult<()> {
-        let lm = self
-            .get_link_manager_unicast(endpoint.protocol().as_str())
-            .await?;
+        let lm = self.get_link_manager_unicast(endpoint).await?;
         lm.del_listener(endpoint).await?;
         if lm.get_listeners().await.is_empty() {
-            self.del_link_manager_unicast(endpoint.protocol().as_str())
-                .await?;
+            self.del_link_manager_unicast(endpoint).await?;
         }
         Ok(())
     }
 
     pub async fn get_listeners_unicast(&self) -> Vec<EndPoint> {
         let mut vec: Vec<EndPoint> = vec![];
-        for p in zasynclock!(self.state.unicast.protocols).values() {
+        for p in zasynclock!(self.state.unicast.link_managers).values() {
             vec.extend_from_slice(&p.get_listeners().await);
         }
         vec
@@ -434,7 +429,7 @@ impl TransportManager {
 
     pub async fn get_locators_unicast(&self) -> Vec<Locator> {
         let mut vec: Vec<Locator> = vec![];
-        for p in zasynclock!(self.state.unicast.protocols).values() {
+        for p in zasynclock!(self.state.unicast.link_managers).values() {
             vec.extend_from_slice(&p.get_locators().await);
         }
         vec
@@ -547,6 +542,17 @@ impl TransportManager {
             };
         }
 
+        // Verify that the node does not try to connect to itself
+        if config.zid == self.zid() {
+            let e = zerror!("{} Attempt to establish transport to itself", self.zid());
+            tracing::warn!("{e}");
+            return Err(InitTransportError::Link((
+                e.into(),
+                link.fail(),
+                close::reason::CONNECTION_TO_SELF,
+            )));
+        }
+
         // Verify that we haven't reached the transport number limit
         if guard.len() >= self.config.unicast.max_sessions {
             let e = zerror!(
@@ -574,12 +580,39 @@ impl TransportManager {
         #[cfg(feature = "stats")]
         let stats = TransportStats::new(Some(Arc::downgrade(&self.get_stats())), labels);
 
+        #[cfg(feature = "shared-memory")]
+        let shm_context = match &config.shm {
+            Some(shm_config) => self.state.shm_context.as_ref().map(|context| {
+                use zenoh_shm::api::protocol_implementations::posix::protocol_id::POSIX_PROTOCOL_ID;
+
+                use crate::{
+                    shm::{LazyShmProvider, PartnerShmConfig},
+                    shm_context::UnicastTransportShmContext,
+                };
+
+                let shm_provider = if shm_config.supports_protocol(POSIX_PROTOCOL_ID) {
+                    context.shm_provider.clone()
+                } else {
+                    Arc::new(LazyShmProvider::new_disabled())
+                };
+
+                UnicastTransportShmContext::new(
+                    context.shm_reader.clone(),
+                    shm_provider,
+                    shm_config.clone(),
+                )
+            }),
+            None => None,
+        };
+
         // Select and create transport implementation depending on the cfg and enabled features
         let t = if config.is_lowlatency {
             tracing::debug!("Will use LowLatency transport!");
             TransportUnicastLowlatency::make(
                 self.clone(),
                 config.clone(),
+                #[cfg(feature = "shared-memory")]
+                shm_context,
                 #[cfg(feature = "stats")]
                 stats,
             )
@@ -589,6 +622,8 @@ impl TransportManager {
                 TransportUnicastUniversal::make(
                     self.clone(),
                     config.clone(),
+                    #[cfg(feature = "shared-memory")]
+                    shm_context,
                     #[cfg(feature = "stats")]
                     stats
                 ),
@@ -739,11 +774,13 @@ impl TransportManager {
         }
 
         // Automatically create a new link manager for the protocol if it does not exist
-        let manager = self
-            .new_link_manager_unicast(endpoint.protocol().as_str())
-            .await?;
+        let manager = self.new_link_manager_unicast(&endpoint).await?;
         // Fill and merge the endpoint configuration
-        if let Some(config) = self.config.endpoints.get(endpoint.protocol().as_str()) {
+        if let Some(config) = self
+            .config
+            .link_configs
+            .get(&LinkKind::try_from(&endpoint)?)
+        {
             let mut config = parameters::Parameters::from(config.as_str());
             // Overwrite config with current endpoint parameters
             config.extend_from_iter(endpoint.config().iter());
